%{
/*
    phoneformat - produce a compact TeX file for a simple address database.
    Copyright (C) 1989-1994  Luigi Semenzato

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    Author's address:
    Computer Science Division
    University of California
    Berkeley, CA 94720
    luigi@cs.berkeley.edu

    This program was developed in the author's own time
    and is not connected in any way to the author's research
    at Berkeley.
*/
#include "y.tab.h"
#include "phones.h"

int LineNo = 1;
char StringTable[200000], *StringTop = StringTable;
char *UniqueStrings[200], **UniqueTop = UniqueStrings;
char *storestring();
char *storeunique();
char *defaultKey = 0;

void lexerror(char *string)
{
    fprintf(stderr, "error at line %d: %s\n", LineNo, string);
    exit (1);
}
%}
%start CHKNAM NAM CHKNUM NUM CHKADDR ADDR CHKKY KY COMM DEFKY
%%
<CHKNAM>\t	lexerror("expected name; found tab");
<CHKNAM>\(	lexerror("expected name; found comment");
<CHKNAM>\n	LineNo++;
<CHKNAM>@	BEGIN DEFKY;
<CHKNAM>@\n	{ yylval.s = 0; LineNo++; return DEFAULT_KEY; }	/* empty key */
<CHKNAM>^%.*$	;			/* ignore lines starting with a % */
<CHKNAM>.	{ BEGIN NAM; yymore(); }

<DEFKY>[^\n]*	{ yylval.s = storeunique(); BEGIN CHKNAM; return DEFAULT_KEY; }

<NAM>[^ \t\n]+	{ yylval.s = storestring(); return NAME; }
<NAM>[ ]	;				/* spaces are separators */
<NAM>[\t]	BEGIN NUM;			/* tabs are meaningful */
<NAM>\n		lexerror("phone expected");

<NUM>\t		;				/* ignore tabs */
<NUM>[^\t\n]+	{ yylval.s = storestring(); return TELNO; }
<NUM>\n		{ BEGIN CHKNUM; LineNo++; }

<CHKNUM>\n	{ BEGIN CHKNAM; LineNo++; }
<CHKNUM>^@	{ BEGIN KY; }
<CHKNUM>\(	{ BEGIN COMM; }
<CHKNUM>\t	{ BEGIN NUM; }
<CHKNUM>[^\t]	{ BEGIN ADDR; yymore(); }

<ADDR>[^\n]+	{ yylval.s = storestring(); return ADDRESS; }
<ADDR>\n	{ LineNo++; BEGIN CHKADDR; }

<CHKADDR>\(	{ BEGIN COMM; }
<CHKADDR>@	{ BEGIN KY; }
<CHKADDR>\n	{ BEGIN CHKNAM; LineNo++; }
<CHKADDR>.	{ BEGIN ADDR; yymore(); }

<COMM>[^)\n]+	{ yylval.s = storestring(); return COMMENT; }
<COMM>\n	LineNo++;
<COMM>\)\n	{ LineNo++; BEGIN CHKKY; }
<COMM>\)[^\n]	{ lexerror("newline expected after end of comment"); }

<CHKKY>@	{ BEGIN KY; }
<CHKKY>\n	{ BEGIN CHKNAM; LineNo++; }
<CHKKY>.	{ lexerror("key or end of entry (empty line) expected"); }

<KY>[^ \n]*	{ yylval.s = storeunique(); return KEY; }
<KY>\n\n	{ BEGIN CHKNAM; LineNo += 2; }
<KY>\n		{ lexerror("blank line expected after keys"); }

.		yyerror();		/* anything else is error */
%%

#include <stdio.h>

lexinit()
{
    BEGIN CHKNAM;
}

yyerror()
{
	fprintf(stderr, "syntax error at line %d reading ``%s''\n",
		LineNo, yytext);
	exit (1);
}

char *
storestring()
{
	register char *to = StringTop, *from = yytext, *start = StringTop;

	while (*to++ = *from++);
	StringTop = to;
	if (StringTop >= StringTable + sizeof(StringTable)) {
		fprintf(stderr, "string table overflow\n");
		exit(1);
	}
	return start;
}

char *storeunique()
{
    char **p = UniqueStrings;
    char *s;
    if (yytext[0] == '\0') return (char *) 0;
    while (p < UniqueTop) {
	if (! strcmp(yytext, *p) ) return *p;
	p++;
    }
    s = storestring();
    *p = s;
    UniqueTop++;
    if (UniqueTop >
	UniqueStrings + sizeof(UniqueStrings) / sizeof(UniqueStrings[0])) {
	fprintf(stderr, "key table overflow\n");
	exit(1);
    }
    return s;
}
