/*
    phoneformat - produce a compact TeX file for a simple address database.
    Copyright (C) 1989-1994  Luigi Semenzato

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    Author's address:
    Computer Science Division
    University of California
    Berkeley, CA 94720
    luigi@cs.berkeley.edu

    This program was developed in the author's own time
    and is not connected in any way to the author's research
    at Berkeley.
*/
char TeXVarious[] = "\
\\nopagenumbers\n\
\\raggedright\n\
\\tolerance=10000\n\
\\hbadness=10000\n\
\\def\\dots{\\leaders\\hbox to 0.6em{\\hss.\\hss}}\n\
\\def\\firstline#1#2{\\noindent\n\
{#1}\\leaders\\hbox to 2.5pt{.}\\hfill\
\\penalty-1\\hbox{}\\leaders\\hbox to 2.5pt{.}\\hfil{#2}\\break}\n\
%%	\\def\\firstline#1#2{\\setbox0=\\hbox{#1}\\setbox1=\\hbox{#2}\n\
%%	\\setbox2=\\hbox{\\copy0\\quad\\copy1}\n\
%%	\\ifdim\\wd2>\\hsize\n\
%%		\\line{\\box0\\leaders\\hbox{.}\\hfill}\n\
%%		\\line{\\leaders\\hbox{.}\\hfill\\box1}\n\
%%	\\else\n\
%%		\\line{\\box0\\leaders\\hbox{.}\\hfill\\box1}\n\
%%	\\fi}\n\
\\parskip 0pt\n\
\\parindent=10pt\n\
\n\
";

char *TeXSeparators[] = {"\
\\def\\separator#1{}\n\
", "\
\\def\\separator#1{\\hrule\\smallskip}\n\
", "\
\\def\\separator#1{\\hbox{\\vrule\\hskip -0.4pt\\vbox{\\hrule\\smallskip\n\
	\\centerline{\\bf{#1}}\\smallskip\\hrule}\\hskip -0.4pt\\vrule}}\n\
", "\
\\def\\separator#1{\\hbox{\\vrule\\hskip -0.4pt\\vbox{\\hrule\\smallskip\n\
	\\centerline{\\bigbf{#1}}\\smallskip\\hrule}\\hskip -0.4pt\\vrule}\n\
	\\medskip}\n\
", "\
\\def\\separator#1{\\smallskip\\centerline{\\bigbf{#1}}\\medskip}\n\
", "\
\\def\\separator#1{\\hrule\\smallskip\n\
	\\centerline{\\bigbf{#1}}\\smallskip\\hrule\\medskip}\n\
", "\
\\def\\cute{$\\sya\\syb\\syc\\syd$}\n\
\\def\\revcute{$\\syd\\syc\\syb\\sya$}\n\
\\let\\sya=\\heartsuit\\let\\syb=\\spadesuit\
  \\let\\syc\\diamondsuit\\let\\syd=\\clubsuit\n\
\\def\\cycle{\\let\\tmp=\\sya\\let\\sya=\\syb\
	       \\let\\syb=\\syc\\let\\syc=\\syd\\let\\syd=\\tmp}\n\
\\def\\separator#1{\\smallskip\n\
    \\hbox to \\hsize{\\hfil\\cute\\hfil\\bigbf{#1}\\hfil\\revcute\\hfil}\n\
    \\cycle\\medskip}\n\
", "\
\\def\\cute{$\\sya\\syb\\syc\\syd$}\n\
\\def\\revcute{$\\syd\\syc\\syb\\sya$}\n\
\\let\\sya=\\heartsuit\\let\\syb=\\spadesuit\
  \\let\\syc\\diamondsuit\\let\\syd=\\clubsuit\n\
\\def\\cycle{\\let\\tmp=\\sya\\let\\sya=\\syb\
	       \\let\\syb=\\syc\\let\\syc=\\syd\\let\\syd=\\tmp}\n\
\\def\\separator#1{\\hbox{\\vrule\\vbox{\\hrule\\smallskip\n\
\\hbox to \\hsize{\\hfil\\cute\\hfil\\bigbf{#1}\\hfil\\revcute\\hfil}\n\
  \\smallskip\\hrule}\\vrule}\\medskip\\cycle}\n\
"};

#define arraysize(A) (sizeof(A) / sizeof(A[0]))

int Nseparators = arraysize(TeXSeparators);

char *TeXFonts[] = {"\
\\font\\rm=cmr6\n\
\\font\\bf=cmbx6\n\
\\font\\it=cmti7			%% wish we had cmti6!!!!\n\
\\font\\bigbf=cmbx10 scaled \\magstep3\n\
\\font\\tt=cmtt8\n\
\\rm\n\
\\baselineskip=6pt\n\
", "\
\\font\\rm=cmr7\n\
\\font\\bf=cmbx7\n\
\\font\\it=cmti7\n\
\\font\\bigbf=cmbx10 scaled \\magstep3\n\
\\font\\tt=cmtt8\n\
\\rm\n\
\\baselineskip=7pt\n\
", "\
\\font\\rm=cmr8\n\
\\font\\bf=cmbx8\n\
\\font\\it=cmti8\n\
\\font\\bigbf=cmbx10 scaled \\magstep3\n\
\\font\\tt=cmtt8\n\
\\rm\n\
\\baselineskip=9pt\n\
", "\
\\font\\rm=cmr9\n\
\\font\\bf=cmbx9\n\
\\font\\it=cmti9\n\
\\font\\bigbf=cmbx10 scaled \\magstep3\n\
\\font\\tt=cmtt9\n\
\\rm\n\
\\baselineskip=10pt\n\
", "\
\\font\\rm=cmr10\n\
\\font\\bf=cmbx10\n\
\\font\\it=cmti10\n\
\\font\\bigbf=cmbx10 scaled \\magstep3\n\
\\font\\tt=cmtt10\n\
\\rm\n\
\\baselineskip=12pt\n\
"};

int Nfonts = arraysize(TeXFonts);

char *TeXPFonts[] = {"\
\\font\\rm=rptmr scaled 600\n\
\\font\\bf=rptmb scaled 600\n\
\\font\\it=rptmri scaled 600\n\
\\font\\bigbf=rptmb scaled \\magstep3\n\
\\font\\tt=rpcrr scaled 600\n\
\\rm\n\
\\baselineskip=6pt\n\
\n\
", "\
\\font\\rm=t-rom scaled 700\n\
\\font\\bf=t-bol scaled 700\n\
\\font\\it=t-ita scaled 700\n\
\\font\\bigbf=t-bol scaled \\magstep3\n\
\\font\\tt=rpcrr scaled 700\n\
\\rm\n\
\\baselineskip=7pt\n\
\n\
", "\
\\font\\rm=t-rom scaled 800\n\
\\font\\bf=t-bol scaled 800\n\
\\font\\it=t-ita scaled 800\n\
\\font\\bigbf=t-bol scaled \\magstep3\n\
\\font\\tt=rpcrr scaled 800\n\
\\rm\n\
\\baselineskip=9pt\n\
\n\
", "\
\\font\\rm=t-rom scaled 900\n\
\\font\\bf=t-bol scaled 900\n\
\\font\\it=t-ita scaled 900\n\
\\font\\bigbf=t-bol scaled \\magstep3\n\
\\font\\tt=rpcrr scaled 900\n\
\\rm\n\
\\baselineskip=10pt\n\
\n\
", "\
\\font\\rm=t-rom scaled 1000\n\
\\font\\bf=t-bol scaled 1000\n\
\\font\\it=t-ita scaled 1000\n\
\\font\\tt=rpcrr scaled 1000\n\
\\font\\bigbf=t-bol scaled \\magstep3\n\
\\rm\n\
\\baselineskip=12pt\n\
\n\
"};

int NPfonts = arraysize(TeXPFonts);

char TeXOversized[] = "\\font\\bigbf=cminch scaled 689\n";

char TeXThreecol[] = "\
\\newdimen\\fullhsize\n\
\\fullhsize=6.5in\n\
\\hsize=2.0in\n\
\\let\\lr=L \\newbox\\leftcolumn \\newbox\\midcolumn\n\
\\output={\\if L\\lr\n\
		\\global\\setbox\\leftcolumn=\\columnbox \\global\\let\\lr=M\n\
	\\else \\if M\\lr\n\
		\\global\\setbox\\midcolumn=\\columnbox \\global\\let\\lr=R\n\
	\\else\n\
		\\tripleformat \\global\\let\\lr=L\n\
	\\fi\\fi\n\
	\\ifnum\\outputpenalty>-20000 \\else\\dosupereject\\fi}\n\
\n\
\\def\\tripleformat\n\
       {\\shipout\\vbox{\\makeheadline\n\
		\\fullline{\\box\\leftcolumn\\hfil\\box\\midcolumn\\hfil\\columnbox}\n\
		\\makefootline}\n\
	\\advancepageno}\n\
\n\
\\def\\columnbox{\\leftline{\\pagebody}}\n\
\n\
\\def\\fullline{\\hbox to \\fullhsize}\n\
\n\
\\def\\byecolumns\n\
	{\\vfill\\supereject\n\
	 \\if L\\lr \\else\\null\\vfill\\eject\\fi\n\
 	 \\if M\\lr \\else\\null\\vfill\\eject\\fi}\n\
";

char TeXFourcol[] = "\
\\newdimen\\fullhsize\n\
\\fullhsize=6.5in\n\
\\hsize=1.5in\n\
\\let\\lr=A \\newbox\\firstcolumn \\newbox\\secondcolumn \\newbox\\thirdcolumn\n\
\\output={\\if A\\lr\n\
		\\global\\setbox\\firstcolumn=\\columnbox \\global\\let\\lr=B\n\
	\\else \\if B\\lr\n\
		\\global\\setbox\\secondcolumn=\\columnbox \\global\\let\\lr=C\n\
	\\else \\if C\\lr\n\
		\\global\\setbox\\thirdcolumn=\\columnbox \\global\\let\\lr=D\n\
	\\else\n\
		\\quadrupleformat \\global\\let\\lr=A\n\
	\\fi\\fi\\fi\n\
	\\ifnum\\outputpenalty>-20000 \\else\\dosupereject\\fi}\n\
\n\
\\def\\quadrupleformat\n\
 {\\shipout\\vbox\n\
  {\\makeheadline\n\
    \\fullline{\\box\\firstcolumn\\hfil\\box\\secondcolumn\\hfil\n\
	      \\box\\thirdcolumn\\hfil\\columnbox}\n\
    \\makefootline}\n\
	\\advancepageno}\n\
\n\
\\def\\columnbox{\\leftline{\\pagebody}}\n\
\n\
\\def\\fullline{\\hbox to \\fullhsize}\n\
\n\
\\def\\byecolumns\n\
	{\\vfill\\supereject\n\
	 \\if A\\lr \\else\\null\\vfill\\eject\\fi\n\
	 \\if B\\lr \\else\\null\\vfill\\eject\\fi\n\
 	 \\if C\\lr \\else\\null\\vfill\\eject\\fi}\n\
\n\
";

char TeXEpilogue[] = "\\bigskip\\hrule\\smallskip\n\
\\noindent {\\bf PRINTED \\number\\day/\
\\number\\month/\\number\\year}\n\
(day/month/year)\\vfill\\byecolumns\n\\bye\n";


char TeXQuad[] = "\n\
\\newdimen\\fullhsize\n\
\\newdimen\\FULLHSIZE\n\
\\newdimen\\fullvsize\n\
\\newdimen\\FULLVSIZE\n\
\\let\\lr=L \\newbox\\leftcolumn \\newbox\\quadrantbox\n\
\\let\\quadrant=A \\newbox\\firstquadrant \\newbox\\secondquadrant\n\
		\\newbox\\thirdquadrant \\newbox\\fourthquadrant\n\
\\output={\\if L\\lr\n\
		\\global\\setbox\\leftcolumn=\\columnbox \\global\\let\\lr=R\n\
	\\else\n\
		\\global\\setbox\\quadrantbox=\\vbox{\\hbox to \\fullhsize\n\
		{\\box\\leftcolumn\\hfil\\columnbox}} \\global\\let\\lr=L\n\
		\\quadrantformat\n\
	\\fi\n\
	\\ifnum\\outputpenalty>-20000 \\else\\dosupereject\\fi}\n\
\n\
\\def\\quadrantformat\n\
	{\\if A\\quadrant\n\
		\\global\\setbox\\firstquadrant=\\box\\quadrantbox\n\
		\\global\\let\\quadrant=B\n\
	\\else \\if B\\quadrant\n\
		\\global\\setbox\\secondquadrant=\\box\\quadrantbox\n\
		\\global\\let\\quadrant=C\n\
	\\else \\if C\\quadrant\n\
		\\global\\setbox\\thirdquadrant=\\box\\quadrantbox\n\
		\\global\\let\\quadrant=D\n\
	\\else\n\
		{\\shipout\n\
		\\vbox to \\FULLVSIZE\n\
		     {\\FULLLINE{\\box\\firstquadrant\\hfil\\box\\secondquadrant}\n\
		      \\vfill\n\
		      \\FULLLINE{\\box\\thirdquadrant\\hfil\\box\\quadrantbox}}}\n\
		\\global\\let\\quadrant=A\n\
		\\advancepageno\n\
	\\fi\\fi\\fi}\n\
\n\
\\def\\columnbox{\\leftline{\\pagebody}}\n\
\n\
\\def\\fullline{\\hbox to \\fullhsize}\n\
\\def\\FULLLINE{\\hbox to \\FULLHSIZE}\n\
\n\
\\def\\byecolumns\n\
       {\\supereject\n\
	\\if R\\lr \\null\\vfill\\eject\\fi}\n\
";

char TeXGrid[] = "\
\\def\\rowspace{\\vbox to 0.2in{}}\n\
\\def\\colspace{\\hbox to 0.2in{}}\n\
\n\
\\hsize=1.5in\n\
\\vsize=2.9in\n\
\n\
\\newcount\\NROW \\NROW=3 \\newcount\\NCOL \\NCOL=4\n\
\n\
\\newcount\\rowindex \\rowindex=0 \\newcount\\colindex \\colindex=0\n\
\n\
\\newbox\\row \\newbox\\page\n\
\\setbox\\row=\\null \\setbox\\page=\\null\n\
\n\
\\output={\\global\\advance\\colindex by 1\n\
	 \\ifnum\\colindex>\\NCOL\n\
	 	\\global\\colindex=1\n\
		\\global\\setbox\\page=\\vbox{\\box\\page\\rowspace\\box\\row}\n\
		\\global\\setbox\\row=\\null\n\
		\\global\\advance\\rowindex by 1\n\
		\\ifnum\\rowindex=\\NROW\n\
			\\global\\rowindex=1\n\
			\\shipout\\box\\page\n\
			\\global\\setbox\\page=\\null\n\
		\\fi\n\
	\\fi\n\
	\\global\\setbox\\row=\\hbox{\\box\\row\\colspace\\columnbox}}\n\
\n\
\\def\\columnbox{\\leftline{\\pagebody}}\n\
\n\
\\def\\byecolumns{\\vfill\\supereject\n\
		\\ifnum\\colindex=1\\null\\vfill\\eject\\fi}\n\
";
